# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/billing.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import metric_pb2 as google_dot_api_dot_metric__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/billing.proto',
  package='google.api',
  syntax='proto3',
  serialized_pb=_b('\n\x18google/api/billing.proto\x12\ngoogle.api\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/metric.proto\"H\n\x07\x42illing\x12\x0f\n\x07metrics\x18\x01 \x03(\t\x12,\n\x05rules\x18\x05 \x03(\x0b\x32\x1d.google.api.BillingStatusRule\"?\n\x11\x42illingStatusRule\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x18\n\x10\x61llowed_statuses\x18\x02 \x03(\tB \n\x0e\x63om.google.apiB\x0c\x42illingProtoP\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_metric__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_BILLING = _descriptor.Descriptor(
  name='Billing',
  full_name='google.api.Billing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metrics', full_name='google.api.Billing.metrics', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rules', full_name='google.api.Billing.rules', index=1,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=167,
)


_BILLINGSTATUSRULE = _descriptor.Descriptor(
  name='BillingStatusRule',
  full_name='google.api.BillingStatusRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='google.api.BillingStatusRule.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='allowed_statuses', full_name='google.api.BillingStatusRule.allowed_statuses', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=232,
)

_BILLING.fields_by_name['rules'].message_type = _BILLINGSTATUSRULE
DESCRIPTOR.message_types_by_name['Billing'] = _BILLING
DESCRIPTOR.message_types_by_name['BillingStatusRule'] = _BILLINGSTATUSRULE

Billing = _reflection.GeneratedProtocolMessageType('Billing', (_message.Message,), dict(
  DESCRIPTOR = _BILLING,
  __module__ = 'google.api.billing_pb2'
  # @@protoc_insertion_point(class_scope:google.api.Billing)
  ))
_sym_db.RegisterMessage(Billing)

BillingStatusRule = _reflection.GeneratedProtocolMessageType('BillingStatusRule', (_message.Message,), dict(
  DESCRIPTOR = _BILLINGSTATUSRULE,
  __module__ = 'google.api.billing_pb2'
  # @@protoc_insertion_point(class_scope:google.api.BillingStatusRule)
  ))
_sym_db.RegisterMessage(BillingStatusRule)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016com.google.apiB\014BillingProtoP\001'))
# @@protoc_insertion_point(module_scope)
